@@ -210,7 +210,6 @@ command_go(struct confmodule *mod, char *arg)
         if (requested_frontend && running_frontend &&
             strcmp(running_frontend, requested_frontend) != 0)
         {
-            struct frontend *old_frontend;
             struct frontend *new_frontend;
 
             /* Shut down the current frontend, but do not delete unless opening
@@ -220,7 +219,7 @@ command_go(struct confmodule *mod, char *arg)
             new_frontend = frontend_new(mod->config, mod->templates, mod->questions);
             if (new_frontend)
             {
-                old_frontend = mod->frontend;
+                struct frontend *old_frontend = mod->frontend;
                 mod->frontend = new_frontend;
                 new_frontend->questions = old_frontend->questions;
                 new_frontend->questions_noninteractive = old_frontend->questions_noninteractive;
