@@ -289,7 +289,7 @@ void cdebconf_gtk_hide_progress(struct frontend * fe)
 static gboolean handle_cancel_key(GtkWidget * widget, GdkEventKey * key,
                                   struct frontend * fe)
 {
-    if (GDK_Escape == key->keyval) {
+    if (GDK_KEY_Escape == key->keyval) {
         cdebconf_gtk_set_answer_goback(fe);
         return TRUE;
     }
